/* 
 * Copyright (c) 2008-2010, FUJITSU LIMITED
 * All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation and/or
 *    other materials provided with the distribution.
 * 
 * 3. Redistributions with modification must carry prominent notices stating that you changed 
 *    the files and the date of any change.
 * 
 * 4. Neither the name of FUJITSU LIMITED nor the names of its contributors may be used
 *    to endorse or promote products derived from this software without specific prior
 *    written permission.
 * 
 * 5. All your rights under this license shall terminate automatically if you fail to
 *    comply  with any of this list of conditions. If your rights under this license terminate,
 *    you agree to cease use and distribution of this software.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;LOSS OF USE,DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.fujitsu.reffi.server.flex.adapters;

import jp.co.fujitsu.reffi.server.flex.factories.S2Factory;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import flex.messaging.Destination;
import flex.messaging.messages.Message;
import flex.messaging.services.remoting.RemotingDestination;
import flex.messaging.services.remoting.adapters.JavaAdapter;

/**
 * <p>[概 要]</p>
 * Seasar2アダプタクラス。
 *
 * <p>[詳 細]</p>
 * FlexからSeasar2のコンテナを呼び出し利用する際のアダプタクラスです。
 *
 * <p>[備 考]</p>
 * 本クラスは現在開発、検証中のため、試験的な提供となります。
 *
 * <p>[環 境]</p>
 * 
 * @author Project Reffi
 */
public class S2Adapter extends JavaAdapter {
	private static final Log LOG = LogFactory.getLog(S2Adapter.class);

	public S2Adapter() {
		this(false);
	}
	
	public S2Adapter(boolean enableManagement) {
		super(enableManagement);
	}

	@Override
	public void setDestination(Destination destination) {
		((RemotingDestination)destination).setFactory(new S2Factory());
		super.setDestination(destination);
	}
	
	@Override
	public Object invoke(Message message) {
		try {
			return super.invoke(message);
		} catch (Exception e) {
			LOG.error("Exception", e);
			throw new RuntimeException(e);
		}
	}
}
